<?php
namespace Pinpoint\Conesso\Model\Repository;
use Pinpoint\Conesso\Api\Data\ContactSyncInterface;
use Pinpoint\Conesso\Api\Repository\ContactsSyncRepositoryInterface;
use Pinpoint\Conesso\Model\ResourceModel\SyncContacts\CollectionFactory;
use Pinpoint\Conesso\Model\ResourceModel\SyncContacts as SyncContactsResourceModel;
use Pinpoint\Conesso\Api\Data\ContactSyncInterfaceFactory;
use Magento\Framework\Exception\CouldNotSaveException;
use Magento\Framework\App\ResourceConnection;

class SyncContactRepository implements ContactsSyncRepositoryInterface
{
    private $syncContactsCollectionFactory;

    private $contactSyncFactory;

    private $syncContactsResourceModel;

    private $connection;

    public function __construct(
        CollectionFactory $syncContactsCollectionFactory,
        SyncContactsResourceModel $syncContactsResourceModel,
        ContactSyncInterfaceFactory $contactSyncFactory,
        ResourceConnection $resourceConnection
    ) {
        $this->contactSyncFactory = $contactSyncFactory;
        $this->syncContactsResourceModel = $syncContactsResourceModel;
        $this->syncContactsCollectionFactory = $syncContactsCollectionFactory;
        $this->connection = $resourceConnection->getConnection();
    }

    public function save(ContactSyncInterface $contactSync)
    {
        try {
            $x = $this->connection->insertOnDuplicate(
                ContactSyncInterface::SCHEMA,
                $contactSync->getData()
            );
            return $x;
        } catch (\Exception $e) {
            throw new CouldNotSaveException(__(
                'Could not save the entity: %1',
                $e->getMessage()
            ));
        }
    }

    public function delete(ContactSyncInterface $contactSync): bool
    {
        $this-> syncContactsResourceModel->delete($contactSync);
        return true;
    }

    public function deleteById(int $id): bool
    {
        try {
            $syncOrders = $this->syncContactsCollectionFactory->create()
                ->addFieldToFilter('id', ['in' => $id]);
            $syncOrders->walk('delete');
            return true;
        } catch (\Exception $e) {
            return false;
        }
    }
}
